@@ -1,22 +1,19 @@
-C Output from Public domain Ratfor, version 1.0
-      subroutine delseg(delsgs,ndel,nadj,madj,npd,x,y,ntot,nerror)
+C Output from Public domain Ratfor, version 1.03
+      subroutine delseg(delsgs,ndel,nadj,madj,npd,x,y,ntot,incseg)
       implicit double precision(a-h,o-z)
       logical value
-      integer tdel
       dimension nadj(-3:ntot,0:madj), x(-3:ntot), y(-3:ntot)
       dimension delsgs(6,ndel)
+      incseg = 0
       npd = ntot-4
       kseg = 0
       do23000 i = 2,npd 
       do23002 j = 1,i-1 
-      call adjchk(i,j,value,nadj,madj,ntot,nerror)
-      if(nerror.gt.0)then
-      return
-      endif
+      call adjchk(i,j,value,nadj,madj,ntot)
       if(value)then
       kseg = kseg+1
       if(kseg .gt. ndel)then
-      nerror = 14
+      incseg = 1
       return
       endif
       delsgs(1,kseg) = x(i)
